==> puppet_3.4.3.orig.tar.gz: puppet-3.4.3/spec/unit/util/colors_spec.rb <==
#!/usr/bin/env ruby
require 'spec_helper'

describe Puppet::Util::Colors do
  include Puppet::Util::Colors

  let (:message) { 'a message' }
  let (:color) { :black }
  let (:subject) { self }

  describe ".console_color" do
    it { should respond_to :console_color }

    it "should generate ANSI escape sequences" do
      subject.console_color(color, message).should == "\e[0;30m#{message}\e[0m"
    end
  end

  describe ".html_color" do
    it { should respond_to :html_color }

    it "should generate an HTML span element and style attribute" do
      subject.html_color(color, message).should =~ /<span style=\"color: #FFA0A0\">#{message}<\/span>/
    end
  end

  describe ".colorize" do
    it { should respond_to :colorize }

    context "ansicolor supported" do
      before :each do
        subject.stubs(:console_has_color?).returns(true)
      end

      it "should colorize console output" do
        Puppet[:color] = true

        subject.expects(:console_color).with(color, message)
        subject.colorize(:black, message)
      end

      it "should not colorize unknown color schemes" do
        Puppet[:color] = :thisisanunknownscheme

        subject.colorize(:black, message).should == message
      end
    end

    context "ansicolor not supported" do
      before :each do
        subject.stubs(:console_has_color?).returns(false)
      end

      it "should not colorize console output" do
        Puppet[:color] = true

        subject.expects(:console_color).never
        subject.colorize(:black, message).should == message
      end

      it "should colorize html output" do
        Puppet[:color] = :html

        subject.expects(:html_color).with(color, message)
        subject.colorize(color, message)
      end
    end
  end
end

==> puppet_3.6.1.orig.tar.gz: puppet-3.6.1/spec/unit/util/colors_spec.rb <==
#!/usr/bin/env ruby
require 'spec_helper'

describe Puppet::Util::Colors do
  include Puppet::Util::Colors

  let (:message) { 'a message' }
  let (:color) { :black }
  let (:subject) { self }

  describe ".console_color" do
    it { should respond_to :console_color }

    it "should generate ANSI escape sequences" do
      subject.console_color(color, message).should == "\e[0;30m#{message}\e[0m"
    end
  end

  describe ".html_color" do
    it { should respond_to :html_color }

    it "should generate an HTML span element and style attribute" do
      subject.html_color(color, message).should =~ /<span style=\"color: #FFA0A0\">#{message}<\/span>/
    end
  end

  describe ".colorize" do
    it { should respond_to :colorize }

    context "ansicolor supported" do
      before :each do
        subject.stubs(:console_has_color?).returns(true)
      end

      it "should colorize console output" do
        Puppet[:color] = true

        subject.expects(:console_color).with(color, message)
        subject.colorize(:black, message)
      end

      it "should not colorize unknown color schemes" do
        Puppet[:color] = :thisisanunknownscheme

        subject.colorize(:black, message).should == message
      end
    end

    context "ansicolor not supported" do
      before :each do
        subject.stubs(:console_has_color?).returns(false)
      end

      it "should not colorize console output" do
        Puppet[:color] = true

        subject.expects(:console_color).never
        subject.colorize(:black, message).should == message
      end

      it "should colorize html output" do
        Puppet[:color] = :html

        subject.expects(:html_color).with(color, message)
        subject.colorize(color, message)
      end
    end
  end

  describe "on Windows", :if => Puppet.features.microsoft_windows? do
    it "expects a trailing embedded NULL character in the wide string" do
      message = "hello"

      console = Puppet::Util::Colors::WideConsole.new
      wstr, nchars = console.string_encode(message)

      expect(nchars).to eq(message.length)

      expect(wstr.length).to eq(nchars + 1)
      expect(wstr[-1].ord).to be_zero
    end
  end
end
